@@ -8,15 +8,16 @@ MAX_RESULTS = 2 # per handler
 
 def _check_requirements():
 	try:
-		import deskbar.beagle
-		return (True, None)
+		import deskbar
+		import beagle
+		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
 	except:
-		return (False, "Could not load deskbar.beagle, deskbar has been compiled without beagle support")
+		return (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, "Could not load beagle, deskbar has been compiled without beagle support", None)
 	
 HANDLERS = {
 	"BeagleLiveHandler" : {
-		"name": _("Live Beagle Queries"),
-		"description": _("Query Beagle automatically as you type."),
+		"name": _("Beagle Live"),
+		"description": _("Search all of your documents (using Beagle), as you type"),
 		# We must see how to detect properly beagle, for now it will fail on creating a new client
 		# when beagle is not available.
 		"requirements" : _check_requirements,
@@ -159,8 +160,8 @@ class BeagleLiveHandler(deskbar.handler.SignallingHandler):
 		self.counter = {}
 		
 	def initialize (self):
-		import deskbar.beagle
-		self.beagle = deskbar.beagle.Client()
+		import beagle
+		self.beagle = beagle.Client()
 		self.ICONS = self.__load_icons()
 	
 	def __load_icons (self):
@@ -172,8 +173,8 @@ class BeagleLiveHandler(deskbar.handler.SignallingHandler):
 		return res
 		
 	def query (self, qstring, qmax=5):
-		import deskbar.beagle
-		beagle_query = deskbar.beagle.Query()
+		import beagle
+		beagle_query = beagle.Query()
 		beagle_query.add_text(qstring)
 		beagle_query.connect("hits-added", self.hits_added, qstring, MAX_RESULTS)
 		self.beagle.send_request_async(beagle_query)
@@ -211,7 +212,9 @@ class BeagleLiveHandler(deskbar.handler.SignallingHandler):
 							result[prop] = cgi.escape(val)
 							break
 					else:
-						result[prop] = None
+						#translators: This is used for unknown values returned by beagle
+						#translators: for example unknown email sender, or unknown note title
+						result[prop] = _("?")
 			
 			hit_matches.append(BeagleLiveMatch(self, result))
 			
